View Source Dequel.Parser.FieldMatch (Dequel v0.6.0)
This modules handles the parsing of the main piece of DEQUEL: a field match.
A field match is for example this part of a query: name: "Frodo Baggins"
and everything in between the field, and value expression.
Summary
Functions
Parses the given binary as field_match.
Functions
Link to this function
bracket_list__0(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__7(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__8(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__18(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__19(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__26(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__27(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__33(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__34(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__40(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__43(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__44(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
bracket_list__45(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__56(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__57(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__62(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__69(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__70(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__75(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
bracket_list__80(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__81(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__88(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__89(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__95(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__96(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__102(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__105(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__106(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
bracket_list__107(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__117(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__118(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__123(rest, acc, stack, context, comb__line, comb__offset)
View Source@spec field_match(binary(), keyword()) :: {:ok, [term()], rest, context, line, byte_offset} | {:error, reason, rest, context, line, byte_offset} when line: {pos_integer(), byte_offset}, byte_offset: pos_integer(), rest: binary(), reason: String.t(), context: map()
Parses the given binary as field_match.
Returns {:ok, [token], rest, context, position, byte_offset} or
{:error, reason, rest, context, line, byte_offset} where position
describes the location of the field_match (start position) as {line, offset_to_start_of_line}.
To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.
Options
:byte_offset- the byte offset for the whole binary, defaults to 0:line- the line and the byte offset into that line, defaults to{1, byte_offset}:context- the initial context value. It will be converted to a map
Link to this function
field_match__5(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__6(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__11(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__13(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__14(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__17(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__26(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__27(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__34(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__35(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__41(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__42(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__48(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__51(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__52(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__53(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__61(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__62(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__67(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__69(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__70(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__73(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__77(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__82(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__83(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__94(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__95(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__105(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__106(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__113(arg, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__115(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__116(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__123(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__125(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__126(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__136(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__137(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__142(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__144(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__145(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__148(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__152(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__157(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__158(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__169(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__170(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__180(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__181(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__186(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__189(arg, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__191(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__192(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__199(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__201(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__202(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__212(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__213(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__218(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__220(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__221(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__224(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__228(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__233(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__234(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__245(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__246(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__256(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__257(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__262(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__270(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__271(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__278(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__279(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__285(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__286(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__292(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__295(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__296(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__297(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__305(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__306(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__311(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__313(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__314(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__317(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__321(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__326(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__327(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__338(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__339(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__349(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__350(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__362(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__363(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__368(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__370(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__371(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__374(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__378(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__383(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__384(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__395(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__396(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__406(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__407(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__412(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__420(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__421(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__426(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__428(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__429(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__432(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__436(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__441(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__442(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__453(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__454(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__464(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__465(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__477(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__478(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__483(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__485(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__486(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__489(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__493(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__498(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__499(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__510(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__511(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__521(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__522(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__527(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__535(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__536(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__541(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__543(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__544(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__547(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__551(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__556(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__557(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__568(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__569(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__579(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__580(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__592(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__593(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__598(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__600(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__601(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__604(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__608(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__613(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__614(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__625(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__626(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__636(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__637(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__642(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__650(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__651(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__656(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__658(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__659(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__662(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__666(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__671(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__672(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__683(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__684(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__694(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__695(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__707(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__712(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__713(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__724(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__725(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__735(rest, acc, stack, context, comb__line, comb__offset)
Link to this function