View Source Dequel.Parser.Token (Dequel v0.7.0)

Token parsers for the Dequel query language (identifiers, strings, operators, etc.).

Field Paths

Field paths are kept as strings in to_field_path/1. The conversion to atoms is deferred to the semantic analysis or adapter layer, which has schema context available to safely convert strings to atoms.

Summary

Functions