View Source Dequel.Parser.FieldMatch (Dequel v0.7.0)
This modules handles the parsing of the main piece of DEQUEL: a field match.
A field match is for example this part of a query: name: "Frodo Baggins"
and everything in between the field, and value expression.
Summary
Functions
Parses the given binary as field_match.
Functions
Link to this function
bracket_list__0(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__7(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__8(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__18(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__19(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__26(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__27(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__33(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__34(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__40(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__43(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__44(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
bracket_list__45(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__56(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__57(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__62(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__69(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__70(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__75(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
bracket_list__80(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__81(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__88(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__89(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__95(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__96(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__102(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__105(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__106(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
bracket_list__107(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__117(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__118(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
bracket_list__123(rest, acc, stack, context, comb__line, comb__offset)
View Source@spec field_match(binary(), keyword()) :: {:ok, [term()], rest, context, line, byte_offset} | {:error, reason, rest, context, line, byte_offset} when line: {pos_integer(), byte_offset}, byte_offset: pos_integer(), rest: binary(), reason: String.t(), context: map()
Parses the given binary as field_match.
Returns {:ok, [token], rest, context, position, byte_offset} or
{:error, reason, rest, context, line, byte_offset} where position
describes the location of the field_match (start position) as {line, offset_to_start_of_line}.
To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.
Options
:byte_offset- the byte offset for the whole binary, defaults to 0:line- the line and the byte offset into that line, defaults to{1, byte_offset}:context- the initial context value. It will be converted to a map
Link to this function
field_match__5(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__6(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__11(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__13(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__14(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__17(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__26(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__27(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__34(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__35(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__41(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__42(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__48(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__51(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__52(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__53(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__61(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__62(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__67(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__69(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__70(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__73(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__77(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__82(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__83(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__94(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__95(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__105(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__106(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__115(arg, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__117(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__118(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__125(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__127(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__128(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__135(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__136(arg, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__144(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__145(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__150(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__152(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__153(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__156(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__160(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__165(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__166(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__177(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__178(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__188(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__189(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__194(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__199(arg, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__201(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__202(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__209(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__211(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__212(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__219(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__220(arg, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__228(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__229(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__234(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__236(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__237(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__240(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__244(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__249(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__250(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__261(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__262(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__272(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__273(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__278(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__286(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__287(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__294(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__295(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__301(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__302(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__308(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__311(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__312(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__313(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__321(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__322(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__327(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__329(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__330(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__333(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__337(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__342(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__343(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__354(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__355(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__365(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__366(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__378(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__379(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__384(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__386(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__387(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__390(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__394(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__399(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__400(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__411(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__412(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__422(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__423(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__428(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__436(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__437(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__442(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__444(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__445(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__448(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__452(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__457(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__458(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__469(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__470(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__480(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__481(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__493(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__494(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__499(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__501(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__502(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__505(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__509(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__514(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__515(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__526(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__527(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__537(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__538(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__543(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__551(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__552(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__557(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__559(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__560(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__563(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__567(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__572(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__573(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__584(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__585(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__595(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__596(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__608(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__609(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__614(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__616(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__617(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__620(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__624(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__629(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__630(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__641(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__642(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__652(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__653(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__658(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__666(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__667(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__672(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__674(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__675(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__678(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)
Link to this function
field_match__682(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__687(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__688(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__699(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__700(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__710(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__711(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__723(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__728(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__729(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__740(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__741(rest, acc, stack, context, comb__line, comb__offset)
Link to this function
field_match__751(rest, acc, stack, context, comb__line, comb__offset)
Link to this function